@@ -36,8 +36,6 @@ public class ControllerGUI extends JFrame implements ActionListener, KeyListener
 		comm = new ControllerListener(addr,port);
 		comm.listener=this;
 		init();
-		pack();
-		show();
 	}
 
 	// Disables the component if there's nothing selected to apply it to
@@ -164,6 +162,10 @@ public class ControllerGUI extends JFrame implements ActionListener, KeyListener
 		JButton but;
 		public ReenableOnClose(JButton b) { but=b; }
 		public void windowClosing(WindowEvent e) {
+			if(but.getActionCommand().equals("raw"))
+				comm.sendInput("!root \"TekkotsuMon\" \"RawCamServer\"");
+			else
+				comm.sendInput("!root \"TekkotsuMon\" \"SegCamServer\"");
 			e.getWindow().dispose();
 			but.setEnabled(true);
 		}
@@ -259,9 +261,13 @@ public class ControllerGUI extends JFrame implements ActionListener, KeyListener
 			estop.close();
 			estop.open();
 		} else if(evt.getActionCommand().equals("raw") || evt.getActionCommand().equals("rle")) {
+			if(evt.getActionCommand().equals("raw"))
+				comm.sendInput("!root \"TekkotsuMon\" \"RawCamServer\"");
+			else
+				comm.sendInput("!root \"TekkotsuMon\" \"SegCamServer\"");
 			String[] tmp=new String[1];
 			tmp[0]=evt.getActionCommand();
-		 	VisionGUI vis=new VisionGUI(comm._host,tmp);
+			VisionGUI vis=new VisionGUI(comm._host,tmp);
 			((JButton)evt.getSource()).setEnabled(false);
 			vis.addWindowListener(new ReenableOnClose((JButton)evt.getSource()));
 			vis.show();
@@ -412,7 +418,7 @@ public class ControllerGUI extends JFrame implements ActionListener, KeyListener
 		inputField.setEnabled(false);
 		inputField.addActionListener(this);
     inputField.addKeyListener(this);
-		inputField.setMaximumSize(new Dimension(inputField.getMaximumSize().width,inputField.getPreferredSize().height));
+		inputField.setPreferredSize(new Dimension(30,inputField.getPreferredSize().height));
 		inputField.setToolTipText("Text from here is passed to selected controls, or the current control if no selection");
 
 		p.add(Box.createVerticalStrut(spacer_size));
@@ -425,6 +431,7 @@ public class ControllerGUI extends JFrame implements ActionListener, KeyListener
 		
 		{
 			Box tmp=Box.createHorizontalBox();
+			tmp.add(Box.createHorizontalGlue());
 			JButton but;
 		 	but=new JButton("Raw Cam");
 			but.setToolTipText("Raw vision");
@@ -436,6 +443,7 @@ public class ControllerGUI extends JFrame implements ActionListener, KeyListener
 			but.addActionListener(this);
 			but.setActionCommand("rle");
 			tmp.add(but);
+			tmp.add(Box.createHorizontalGlue());
 			tmp.setAlignmentX(0.0f);
 			p.add(tmp);
 		}
@@ -498,8 +506,12 @@ public class ControllerGUI extends JFrame implements ActionListener, KeyListener
 		int numScripts=prefs.getInt("ControllerGUI.numScripts",0);
 		for(int i=0; i<numScripts; i++)
 			scriptsModel.addElement(new ScriptEntry(prefs.get("ControllerGUI.script"+i+".title","unknown"),prefs.get("ControllerGUI.script"+i+".cmd","")));
+
+		pack();
+		show();
+		getRootPane().setMinimumSize(getRootPane().getSize());
 	}
-	
+
 	class CloseVisionAdapter extends WindowAdapter {
 		ControllerGUI gui;
 		CloseVisionAdapter(ControllerGUI gui) {this.gui=gui;}
